@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-"""
-"""
+
+from typing import Union
 
 import pathlib
 
@@ -8,7 +8,7 @@ from qtpy import QtCore
 
 
 class Url(QtCore.QUrl):
-    def __init__(self, path):
+    def __init__(self, path: Union[QtCore.QUrl, str, pathlib.Path]):
 
         super().__init__(str(path) if not isinstance(path, QtCore.QUrl) else path)
         if isinstance(path, pathlib.Path):
@@ -24,7 +24,7 @@ class Url(QtCore.QUrl):
         return self.toString(self.PreferLocalFile)
 
     def to_path(self) -> pathlib.Path:
-        """get pathlib object from the URL
+        """Get pathlib object from the URL.
 
         Returns:
             Path
