@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from qtpy import QtCore, QtGui
 
@@ -61,7 +59,7 @@ class Painter(QtGui.QPainter):
         self.fillRect(rect, color)
 
     def set_pen(self, pen_type: str):
-        """set pen type to use
+        """Set pen type to use.
 
         Allowed values are "none",
 
@@ -76,7 +74,7 @@ class Painter(QtGui.QPainter):
         self.setPen(PEN_TYPES[pen_type])
 
     def get_pen(self) -> str:
-        """returns current pen type
+        """Return current pen type.
 
         Possible values: "none",
 
@@ -90,7 +88,7 @@ class Painter(QtGui.QPainter):
         self.setPen(color)
 
     def set_composition_mode(self, mode: str):
-        """set the current composition mode
+        """Set the current composition mode.
 
         Possible values: "source_over", "destination_over", "clear", "source",
                          "destination", "source_in", "destination_in", "source_out",
@@ -106,7 +104,7 @@ class Painter(QtGui.QPainter):
         self.setCompositionMode(COMP_MODES[mode])
 
     def get_composition_mode(self) -> str:
-        """get the current composition mode
+        """Get the current composition mode.
 
         Possible values: "source_over", "destination_over", "clear", "source",
                          "destination", "source_in", "destination_in", "source_out",
