@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-"""
+"""Module containing helper functions."""
 
 import bidict as bdct
 
