@@ -1,9 +1,5 @@
 # -*- coding: utf-8 -*-
-"""
-
-for full list, see:
-- https://cdn.materialdesignicons.com/3.0.39/
-"""
+"""For full list, see: https://cdn.materialdesignicons.com/4.9.95/ ."""
 
 import qtawesome as qta
 
