@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from qtpy import QtWidgets
 
@@ -17,16 +15,12 @@ QtWidgets.QAbstractButton.__bases__ = (widgets.Widget,)
 
 
 class AbstractButton(QtWidgets.QAbstractButton):
-    def __getstate__(self):
+    def serialize_fields(self):
         return dict(
-            object_name=self.id,
             text=self.text(),
             icon=gui.Icon(self.icon()) if not self.icon().isNull() else None,
             checkable=self.isCheckable(),
             checked=self.isChecked(),
-            tooltip=self.toolTip(),
-            statustip=self.statusTip(),
-            enabled=self.isEnabled(),
         )
 
     def __setstate__(self, state):
@@ -41,7 +35,7 @@ class AbstractButton(QtWidgets.QAbstractButton):
         self.setStatusTip(state.get("statustip", ""))
 
     def set_icon(self, icon: gui.icon.IconType):
-        """set the icon for the button
+        """Set the icon for the button.
 
         Args:
             icon: icon to use
