@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
-from qtpy import QtWidgets
+from typing import Union, Optional
 
+from qtpy import QtWidgets, QtCore
 from prettyqt import widgets
 
 
@@ -11,11 +10,15 @@ QtWidgets.QGridLayout.__bases__ = (widgets.Layout,)
 
 
 class GridLayout(QtWidgets.QGridLayout):
-    def __getitem__(self, idx):
+    def __getitem__(
+        self, idx: Union[tuple, int, str]
+    ) -> Optional[Union[QtWidgets.QWidget, QtWidgets.QLayout]]:
         if isinstance(idx, tuple):
             item = self.itemAtPosition(*idx)
-        else:
+        elif isinstance(idx, int):
             item = self.itemAt(idx)
+        else:
+            return self.find_child(QtCore.QObject, idx)
         widget = item.widget()
         if widget is None:
             widget = item.layout()
@@ -29,7 +32,7 @@ class GridLayout(QtWidgets.QGridLayout):
         colstart = col.start if isinstance(col, slice) else col
         self.add(value, rowstart, colstart, rowspan, colspan)
 
-    def __getstate__(self):
+    def serialize_fields(self):
         widgets = []
         positions = []
         for i, item in enumerate(list(self)):
@@ -47,14 +50,20 @@ class GridLayout(QtWidgets.QGridLayout):
         return iter(self[i] for i in range(self.count()) if self[i] is not None)
 
     def __add__(self, other):
-        self[self.rowCount(), 0 : self.columnCount() - 1] = other
+        if isinstance(other, (tuple, list)):
+            for i, control in enumerate(other):
+                self[self.rowCount(), i] = other
+        else:
+            self[self.rowCount(), 0 : self.columnCount() - 1] = other
         return self
 
     def add(self, item, rowstart, colstart, rowspan=1, colspan=1):
         if isinstance(item, QtWidgets.QWidget):
             self.addWidget(item, rowstart, colstart, rowspan, colspan)
-        else:
+        elif isinstance(item, QtWidgets.QLayout):
             self.addLayout(item, rowstart, colstart, rowspan, colspan)
+        else:
+            self.addItem(item, rowstart, colstart, rowspan, colspan)
 
     def append(self, item):
         self[self.rowCount(), 0 : self.columnCount() - 1] = item
