@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 import contextlib
 from typing import Optional
@@ -47,12 +45,9 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
         self.textChanged.connect(self._on_value_change)
         self.set_read_only(read_only)
 
-    def __getstate__(self):
+    def serialize_fields(self):
         return dict(
-            text=self.text(),
-            enabled=self.isEnabled(),
-            read_only=self.isReadOnly(),
-            font=gui.Font(self.font()),
+            text=self.text(), read_only=self.isReadOnly(), font=gui.Font(self.font()),
         )
 
     def __setstate__(self, state):
@@ -68,9 +63,7 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
             return self
 
     def wheelEvent(self, event):
-        """
-        handle wheel event for zooming
-        """
+        """Handle wheel event for zooming."""
         if not self._allow_wheel_zoom:
             return None
         if event.modifiers() & constants.CTRL_MOD:
@@ -122,7 +115,7 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
             c.select_text(start, end)
 
     def set_read_only(self, value: bool = True):
-        """make the PlainTextEdit read-only
+        """Make the PlainTextEdit read-only.
 
         Args:
             value: True, for read-only, otherwise False
@@ -144,7 +137,7 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
         self.setExtraSelections(extra_selections)
 
     def set_wrap_mode(self, mode: str):
-        """set word wrap mode
+        """Set word wrap mode.
 
         Allowed values are "none", "word", "anywhere", "boundary_or_anywhere"
 
@@ -159,7 +152,7 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
         self.setWordWrapMode(WRAP_MODES[mode])
 
     def set_line_wrap_mode(self, mode: str):
-        """set line wrap mode
+        """Set line wrap mode.
 
         Allowed values are "none" and "widget width"
 
