@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from typing import Optional, Union
 
@@ -37,20 +35,9 @@ class Slider(QtWidgets.QSlider):
         super().__init__(orientation, parent)
         self.valueChanged.connect(self.on_value_change)
 
-    def __getstate__(self):
+    def serialize_fields(self):
         return dict(
-            range=(self.minimum(), self.maximum()),
-            value=self.value(),
-            tooltip=self.toolTip(),
-            statustip=self.statusTip(),
-            enabled=self.isEnabled(),
-            has_tracking=self.hasTracking(),
-            tick_position=self.get_tick_position(),
-            tick_interval=self.tickInterval(),
-            inverted_controls=self.invertedControls(),
-            inverted_appearance=self.invertedAppearance(),
-            single_step=self.singleStep(),
-            page_step=self.pageStep(),
+            tick_position=self.get_tick_position(), tick_interval=self.tickInterval(),
         )
 
     def __setstate__(self, state):
@@ -69,7 +56,7 @@ class Slider(QtWidgets.QSlider):
         self.setTickInterval(state["tick_interval"])
 
     def set_tick_position(self, position: str):
-        """sets the tick position for the slider
+        """Set the tick position for the slider.
 
         allowed values are "none", "both_sides", "above", "below", "left", "right"
         for vertical orientation of the slider,
@@ -87,7 +74,7 @@ class Slider(QtWidgets.QSlider):
         self.setTickPosition(TICK_POSITIONS[position])
 
     def get_tick_position(self) -> str:
-        """returns tick position
+        """Return tick position.
 
         possible values are "none", "both_sides", "above", "below"
 
