@@ -83,6 +83,14 @@ class Widget(QtWidgets.QWidget):
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}: {self.serialize_fields()}"
 
+    def __setstate__(self, state: Dict[str, Any]) -> None:
+        super().__init__()
+        self.set_layout(state["layout"])
+        self.setSizePolicy(state["size_policy"])
+        self.setAccessibleName(state["accessible_name"])
+        self.setToolTip(state.get("tooltip", ""))
+        self.setStatusTip(state.get("statustip", ""))
+
     def __pretty__(
         self, fmt: Callable[[Any], Any], **kwargs: Any
     ) -> Generator[Any, None, None]:
@@ -93,7 +101,11 @@ class Widget(QtWidgets.QWidget):
         yield self.__class__.__name__ + "("
         yield 1
         for k, v in self.serialize().items():
-            yield f"{k}={v!r}"
+            yield f"{k}="
+            if hasattr(v, "__pretty__"):
+                yield from v.__pretty__(fmt, **kwargs)
+            else:
+                yield f"{v!r}"
             yield 0
         yield -1
         yield ")"
@@ -109,6 +121,7 @@ class Widget(QtWidgets.QWidget):
             window_title=self.windowTitle(),
             enabled=self.isEnabled(),
             visible=self.isVisible(),
+            stylesheet=self.styleSheet(),
             icon=icon if not icon.isNull() else None,
             modality=self.get_modality(),
             whats_this=self.whatsThis(),
@@ -117,14 +130,6 @@ class Widget(QtWidgets.QWidget):
             statustip=self.statusTip(),
         )
 
-    def __setstate__(self, state: Dict[str, Any]) -> None:
-        super().__init__()
-        self.set_layout(state["layout"])
-        self.setSizePolicy(state["size_policy"])
-        self.setAccessibleName(state["accessible_name"])
-        self.setToolTip(state.get("tooltip", ""))
-        self.setStatusTip(state.get("statustip", ""))
-
     def resize(self, *size) -> None:
         if isinstance(size[0], tuple):
             super().resize(*size[0])
