@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-"""gui module
+"""winextras module.
 
-contains QWebEngineView-based classes
+contains QtWinExtras-based classes
 """
 
 try:
